@@ -8,11 +8,11 @@
  * project      : (X)MedCon by Erik Nolf                                   *
  *                                                                         *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
-/* $Id: m-config.h.in,v 1.23 2011/12/27 00:46:06 enlf Exp $
+/* $Id: m-config.h.in,v 1.25 2013/06/23 21:51:19 enlf Exp $
  */
 
 /*
-   Copyright (C) 1997-2012 by Erik Nolf
+   Copyright (C) 1997-2013 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -33,12 +33,12 @@
 
 /* Define some version variables */
 #define XMEDCON_MAJOR    "0"
-#define XMEDCON_MINOR    "12"
+#define XMEDCON_MINOR    "13"
 #define XMEDCON_MICRO    "0"
 #define XMEDCON_PRGR     "(X)MedCon"
-#define XMEDCON_DATE     "23-nov-2012"
-#define XMEDCON_VERSION  "0.12.0"
-#define XMEDCON_LIBVERS  "(X)MedCon 0.12.0 by Erik Nolf"
+#define XMEDCON_DATE     "23-jun-2013"
+#define XMEDCON_VERSION  "0.13.0"
+#define XMEDCON_LIBVERS  "(X)MedCon 0.13.0 by Erik Nolf"
 
 /* Define if format enabled */
 #define MDC_INCLUDE_ACR   1
@@ -79,8 +79,8 @@
 #    define XMDCLUT  "C:\\Program Files\\XMedCon\\etc\\"
 #    define XMDCRC   "C:\\Program Files\\XMedCon\\etc\\xmedconrc"
 #  else
-#    define XMDCLUT  "/etc/"
-#    define XMDCRC   "/etc/xmedconrc"
+#    define XMDCLUT  "/usr/local/etc/"
+#    define XMDCRC   "/usr/local/etc/xmedconrc"
 #  endif
 #endif
 
